@@ -1,7 +1,7 @@
 
 /*  $Header$
  *
- *  Copyright (c) 1987-2007 Sun Microsystems, Inc. All Rights Reserved.
+ *  Copyright (c) 1987-2008 Sun Microsystems, Inc. All Rights Reserved.
  *           
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -207,6 +207,12 @@ struct button buttons[NKEYS] = {
 {
     KEY_BACKSPACE,
     NULL,
+    do_backspace,
+    0
+},
+{
+    KEY_DELETE,
+    NULL,
     do_delete,
     0
 },
@@ -366,6 +372,12 @@ struct button buttons[NKEYS] = {
     do_immed, 
     FUNC
 },
+{
+    KEY_LOGARITHM2,
+    "Log2",
+    do_immed, 
+    FUNC
+},
 {
     KEY_ABSOLUTE_VALUE,
     "Abs",
@@ -554,7 +566,7 @@ init_text()         /* Setup constant strings. */
     STRNCPY(v->con_names[0], _("Kilometer-to-mile conversion factor"),
             MAXLINE - 1);
     STRNCPY(v->con_names[1], _("square root of 2"), MAXLINE - 1);
-    STRNCPY(v->con_names[2], _("e"), MAXLINE - 1);
+    STRNCPY(v->con_names[2], _("Euler's Number (e)"), MAXLINE - 1);
     STRNCPY(v->con_names[3], _("pi"), MAXLINE - 1);
     STRNCPY(v->con_names[4], _("Centimeter-to-inch conversion factor"),
             MAXLINE - 1);
@@ -707,7 +719,7 @@ init_state(void)
         mpcim(&n, v->MPmvals[i]);
     }
     
-    exp_del();
+    exp_clear();
 }
 
 
@@ -750,7 +762,10 @@ main(int argc, char **argv)
     show_display(v->MPdisp_val);     /* Output in correct display mode. */
 
     memset(&(v->h), 0, sizeof(struct exprm_state_history)); /* clear expression mode state history*/
-
+    struct exprm_state *e;
+    e = get_state();
+    e->clear = 1;              /* Clear initial state as if clear was pressed */
+    
     ui_start();                    /* Display the calculator. */
     
     return(0);
