@@ -1,7 +1,7 @@
 
 /*  $Header$
  *
- *  Copyright (c) 1987-2007 Sun Microsystems, Inc. All Rights Reserved.
+ *  Copyright (c) 1987-2008 Sun Microsystems, Inc. All Rights Reserved.
  *           
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -101,6 +101,7 @@ enum
     KEY_TAN, KEY_TANH, KEY_ATAN, KEY_ATANH,
     KEY_NATURAL_LOGARITHM,
     KEY_LOGARITHM,
+    KEY_LOGARITHM2,
     KEY_ABSOLUTE_VALUE,
     KEY_MASK_16,
     KEY_MASK_32,
@@ -185,6 +186,7 @@ struct exprm_state {
     int ans[MP_SIZE];      /* Previously calculated answer */
     char *expression;      /* Expression entered by user */
     int cursor;
+    int clear;             /* Clear command issued */
 };
 
 /* Circular list of Arithmetic Precedence Mode states*/ 
